# intrade

The intrade Python package provides a unified toolkit for international trade empirical analysis.

## Installation

```bash
pip install intrade
```

## Basic usage

```python
# Import package
import intrade as it

# Import function
from intrade import load_Test
print(it.load_Test("WWZ"))
```
